Assess the AIC for all models in a list of models
# S3 method for list
AIC(object, ..., assess.best = TRUE)a data frame with row names matching the names of the list
x and columns for degrees of freedom (df) and
AIC. If assess.best is true, then there will be
another column isBest.
the list of models
parameters passed to the underlying AIC function (typically the parameter k)
determine which model is the best (by lowest AIC)
get.best.model