Choose either the value from an option list or the current set value for an option.
PKNCA.choose.option(name, value = NULL, options = list())The value of the option first from the options list and if it is
not there then from the current settings.
The option name requested.
A value to check for the option (NULL to choose not to check
the value).
List of changes to the default PKNCA options (see
PKNCA.options())
Other PKNCA calculation and summary settings:
PKNCA.options(),
PKNCA.set.summary()