Skip to contents

Unlike PKNCA.options(default = TRUE), which resets the current options to their defaults, this only reads the default values.

Usage

PKNCA_options_defaults(name = NULL)

Arguments

name

The option name(s) requested, or NULL for all options.

Value

For one name, the default value of that option; otherwise, a named list of default values (all options when name is NULL).

See also

Examples

PKNCA_options_defaults("min.span.ratio")
#> [1] 2
# The current options are not changed
PKNCA.options(min.span.ratio = 3)
PKNCA_options_defaults("min.span.ratio")
#> [1] 2
PKNCA.options("min.span.ratio")
#> [1] 3
PKNCA.options(default = TRUE)