Determine if there are any sparse or dense calculations requested within an interval
Source:R/pk.calc.all.R
any_sparse_dense_in_interval.RdA calculation is sparse when only sparse data can produce it, which is a
property of the registration rather than a flag; see add.interval.col().