Skip to contents

be_table() takes the parameters from be_extract_param() and a regulatory framework and produces the final per-endpoint pass/fail table. It selects the regulator-appropriate statistic (the model contrast for the expanding-limits frameworks, intra-subject contrasts for the FDA family) and calls the per-framework decision functions; it is the only place regulator decisions are made.

Usage

be_table(
  params,
  regulator,
  alpha = 0.1,
  design = NA_character_,
  model_type = NA_character_
)

Arguments

params

A data.frame of parameters from be_extract_param() (with an endpoint column added per endpoint).

regulator

A regulator name or a be_regulator object.

alpha

The significance level.

design

The design label (character) for the design column.

model_type

The model type label for the model_type column.

Value

A data.frame with one row per endpoint and test formulation and the pass/fail decision columns.