Skip to contents

Extract the best model from a list of models using the AIC.

Usage

get.best.model(object, ...)

Arguments

object

the list of models

...

Passed to AIC()

Value

The model which is assessed as best. If more than one are equal, the first is chosen.