Normalize PKNCA results by a column of the concentration data
Source:R/normalize.R
normalize_by_col.RdNormalize PKNCA results by a column of the concentration data
Arguments
- object
A PKNCAresults object
- col
The column name from PKNCAconc to use for the normalization groups
- unit
The unit of the previous column for normalization. Can be a column name in PKNCAconc or a single value.
- parameters
Character vector of parameter names to normalize
- suffix
Suffix to add to the normalized parameter code names