Learn R Programming

PKNCA (version 0.10.2)

pk.calc.cstart: Determine the concentration at the beginning of the interval

Description

Determine the concentration at the beginning of the interval

Usage

pk.calc.cstart(conc, time, start)

Value

The concentration when time == end. If none match, then NA

Arguments

conc

Observed concentrations during the interval

time

Times of conc observations

start

Start time of the interval

See Also

Other NCA parameters for concentrations during the intervals: pk.calc.clast.obs(), pk.calc.cmax(), pk.calc.ctrough()