Skip to contents

Calculate the last measurable excretion rate

Usage

pk.calc.erlst(conc, volume, time, duration.conc, check = TRUE)

Arguments

conc

The concentration in the excreta (e.g., urine or feces)

volume

The volume (or mass) of the sample

time

The starting time of the collection interval

duration.conc

The duration of the collection interval

check

Should the concentration data be checked?

Value

The last measurable (positive) excretion rate, or NA if not available

Details

Collections are ordered by their midpoint time, matching pk.calc.ertlst(), which gives the midpoint time of this same collection. When no collection has a positive excretion rate, the result is 0.