The AUC is calculated as:
pk.calc.sparse_auc(
conc,
time,
subject,
method = NULL,
auc.type = "AUClast",
...,
options = list()
)pk.calc.sparse_auclast(conc, time, subject, ..., options = list())
Concentration measured
Time of concentration measurement (must be monotonically increasing and the same length as the concentration data)
Subject identifiers (may be any class; may not be null)
The method for integration (either 'lin up/log down' or 'linear')
The type of AUC to compute. Choices are 'AUCinf', 'AUClast', and 'AUCall'.
For functions other than pk.calc.auxc, these values are
passed to pk.calc.auxc
List of changes to the default PKNCA.options for
calculations.
pk.calc.sparse_auclast(): Compute the AUClast for sparse PK
$$AUC=\sum\limits_{i} w_i \bar{C}_i$$
Where:
\(AUC\)is the estimated area under the concentration-time curve
\(w_i\)is the weight applied to the concentration at time i (related to the time which it affects, see sparse_auc_weight_linear)
\(\bar{C}_i\)is the average concentration at time i
Other Sparse Methods:
as_sparse_pk(),
sparse_auc_weight_linear(),
sparse_mean()