Interpolation is performed aligning with PKNCA.options("auc.method").
Extrapolation outside of the measured times is not yet implemented. The
method may be changed by giving a named method argument, as
well.
pk.calc.time_above(conc, time, conc_above, ..., options = list(), check = TRUE)the time above the given concentration
Concentration measured
Time of concentration measurement (must be monotonically increasing and the same length as the concentration data)
The concentration to be above
Extra arguments. Currently, the only extra argument that is used
is method as described in the details section.
List of changes to the default PKNCA.options for
calculations.
Run check.conc.time, clean.conc.blq,
and clean.conc.na?
For 'lin up/log down', if clast is above conc_above and
there are concentrations BLQ after that, linear down is used to extrapolate
to the BLQ concentration (equivalent to AUCall).