Skip to contents

Input restrictions are:

  1. the conc and time must be the same length,

  2. the time may have no NAs,

NA will be returned if:

  1. the length of conc and time is 0

  2. all conc is NA

Usage

pk.calc.tmin(conc, time, options = list(), first.tmin = NULL, check = TRUE)

Arguments

conc

Measured concentrations

time

Time of the measurement of the concentrations

options

List of changes to the default PKNCA options (see PKNCA.options())

first.tmin

If there is more than one time point with the minimum value (Cmin), which time should be selected for Tmin? If 'TRUE', the first will be selected. If not, then the last is considered Tmin.

check

Run assert_conc_time()?

Value

The time of the minimum concentration

Examples

conc_data <- Theoph[Theoph$Subject == 1,]
pk.calc.tmin(conc = conc_data$conc, time = conc_data$Time)
#> [1] 0