Skip to contents

Named argument sets for building an interval specification

Usage

pknca_presets()

Value

A named list of the arguments each preset gives to pknca_interval_table(). Arguments given to that function directly override the preset.

Examples

names(pknca_presets())
#> [1] "single_dose"        "steady_state"       "bioequivalence"    
#> [4] "first_in_human"     "mass_balance"       "sparse_single_dose"
pknca_presets()$bioequivalence
#> $dosing
#> [1] "single"
#> 
#> $route
#> [1] "extravascular"
#> 
#> $include
#> [1] "aucall"    "clast.obs" "tlast"    
#>