PKNCAdata combines PKNCAconc and PKNCAdose and
adds in the intervals for PK calculations.
PKNCAdata(data.conc, data.dose, ...)# S3 method for PKNCAconc
PKNCAdata(data.conc, data.dose, ...)
# S3 method for PKNCAdose
PKNCAdata(data.conc, data.dose, ...)
# S3 method for default
PKNCAdata(
data.conc,
data.dose,
...,
formula.conc,
formula.dose,
impute = NA_character_,
intervals,
units,
options = list()
)
A PKNCAdata object with concentration, dose, interval, and calculation options stored (note that PKNCAdata objects can also have results after a NCA calculations are done to the data).
Concentration data as a PKNCAconc object or a
data frame
Dosing data as a PKNCAdose object (see
details)
arguments passed to PKNCAdata.default
Formula for making a PKNCAconc object with
data.conc. This must be given if data.conc is a
data.frame, and it must not be given if data.conc is a
PKNCAconc object.
Formula for making a PKNCAdose object with
data.dose. This must be given if data.dose is a
data.frame, and it must not be given if data.dose is a
PKNCAdose object.
Methods for imputation. NA for no imputation, a
comma-or space-separated list of names, or the name of a column in the
intervals data.frame. See
vignette("v08-data-imputation", package="PKNCA") for more details.
A data frame with the AUC interval specifications as
defined in check.interval.specification. If missing,
this will be automatically chosen by
choose.auc.intervals. (see details)
A data.frame of unit assignments and conversions as created by
pknca_units_table()
List of changes to the default
PKNCA.options for calculations.
If data.dose is not given or is NA, then the
intervals must be given. At least one of data.dose
and intervals must be given.
choose.auc.intervals, pk.nca,
pknca_units_table()
Other PKNCA objects:
PKNCAconc(),
PKNCAdose(),
PKNCAresults()