Extract the parameter results from a PKNCAresults and return them as a data.frame.
Source:R/class-PKNCAresults.R
as.data.frame.PKNCAresults.RdExtract the parameter results from a PKNCAresults and return them as a data.frame.
Usage
# S3 method for class 'PKNCAresults'
as.data.frame(
x,
...,
out_format = c("long", "wide", "cdisc"),
filter_requested = FALSE,
filter_excluded = FALSE,
out.format = deprecated()
)Arguments
- x
The object to extract results from
- ...
Ignored (for compatibility with generic
as.data.frame())- out_format
Should the output be 'long' (default), 'wide', or 'cdisc'? When 'cdisc', the PPTESTCD column is translated to CDISC standard codes and a PPTEST column with the CDISC test name is added. Route-dependent parameters (e.g. CL, VZ, MRT) are resolved using the route information from the dose data.
- filter_requested
Only return rows with parameters that were specifically requested?
- filter_excluded
Should excluded values be removed?
- out.format
Deprecated in favor of
out_format