Take in a single row of an interval specification and return that row updated with any additional calculations that must be done to fulfill all dependencies.
check.interval.deps(x)A data frame with one or morw rows of the PKNCA interval
The interval specification with additional calculations added where requested outputs require them.
Other Interval specifications:
add.interval.col(),
check.interval.specification(),
choose.auc.intervals(),
get.interval.cols(),
get.parameter.deps()