Subset data to the rows used for calculations within an interval
Source:R/pk.calc.all.R
filter_interval.RdRows are selected by their time falling within the interval: start <= time and time <= end (or time < end when include_end=FALSE). For
duration data (for example, urine collections or intravenous infusions),
time is the start of the collection or administration, and the duration
column is not consulted during selection: a record whose duration starts
within the interval and ends after the interval end is selected and
contributes its full amount to calculations within the interval. For the
simplest interpretation of results, align collection start and end times
with interval boundaries.