R/AIC.list.R
get.best.model.Rd
Extract the best model from a list of models using the AIC.
get.best.model(object, ...)
the list of models
Passed to AIC()
AIC()
The model which is assessed as best. If more than one are equal, the first is chosen.