dplyr joins for PKNCA
# S3 method for PKNCAresults
inner_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)# S3 method for PKNCAresults
left_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAresults
right_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAresults
full_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAconc
inner_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAconc
left_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAconc
right_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAconc
full_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAdose
inner_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAdose
left_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAdose
right_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
# S3 method for PKNCAdose
full_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = FALSE
)
A pair of data frames, data frame extensions (e.g. a tibble), or lazy data frames (e.g. from dbplyr or dtplyr). See Methods, below, for more details.
A character vector of variables to join by.
If NULL, the default, *_join() will perform a natural join, using all
variables in common across x and y. A message lists the variables so that you
can check they're correct; suppress the message by supplying by explicitly.
To join by different variables on x and y, use a named vector.
For example, by = c("a" = "b") will match x$a to y$b.
To join by multiple variables, use a vector with length > 1.
For example, by = c("a", "b") will match x$a to y$a and x$b to
y$b. Use a named vector to match different variables in x and y.
For example, by = c("a" = "b", "c" = "d") will match x$a to y$b and
x$c to y$d.
To perform a cross-join, generating all combinations of x and y,
use by = character().
If x and y are not from the same data source,
and copy is TRUE, then y will be copied into the
same src as x. This allows you to join tables across srcs, but
it is a potentially expensive operation so you must opt into it.
If there are non-joined duplicate variables in x and
y, these suffixes will be added to the output to disambiguate them.
Should be a character vector of length 2.
Other parameters passed onto methods.
Should the join keys from both x and y be preserved in the
output?
Other dplyr verbs:
filter.PKNCAresults(),
group_by.PKNCAresults(),
mutate.PKNCAresults()