Calculate AUXC (AUC or AUMC) for IV dosing with C0 back-extrapolation
Source:R/auciv.R
pk.calc.auxciv.RdCalculates AUC or AUMC for intravenous dosing, with optional back-extrapolation to C0.
Usage
pk.calc.auxciv(
conc,
time,
c0,
auxc,
fun_auxc_last,
fun_auxc,
auc.type = NULL,
lambda.z = NA,
clast = NA,
...,
options = list(),
check = TRUE
)
pk.calc.auciv(
conc,
time,
c0,
auc,
auc.type = NULL,
lambda.z = NA,
clast = NA,
...,
options = list(),
check = TRUE
)
pk.calc.auciv_pbext(
conc,
time,
auc,
auciv,
...,
options = list(),
check = TRUE
)
pk.calc.aumciv(
conc,
time,
c0,
aumc,
auc.type = NULL,
lambda.z = NA,
clast = NA,
...,
options = list(),
check = TRUE
)Arguments
- conc
Measured concentrations
- time
Time of the measurement of the concentrations
- c0
The concentration at time 0, typically calculated using
pk.calc.c0()- auxc
The AUXC calculated using
concandtimewithoutc0(it may be calculated using any method)- fun_auxc_last
Function to calculate the AUXC for the last interval (e.g.,
pk.calc.auc.lastorpk.calc.aumc.last)- fun_auxc
Function to calculate the AUXC over the full interval when
auxccould not be calculated (e.g.,pk.calc.aucorpk.calc.aumc)- auc.type
The type of AUXC for
fun_auxcto calculate.NULL(the default) means that the AUXC will not be calculated fromc0and the measured data, soNAis returned whenauxcisNA.- lambda.z
The elimination rate (in units of inverse time) for extrapolation
- clast
The last concentration above the limit of quantification, used by
fun_auxcwhenauc.typeis"AUCinf"(clast.obsgives AUCinf,obs andclast.predgives AUCinf,pred)- ...
For functions other than
pk.calc.auxc, these values are passed topk.calc.auxc- options
List of changes to the default PKNCA options (see
PKNCA.options())- check
Run
assert_conc_time()?- auc
The AUC calculated without C0 back-extrapolation
- auciv
The AUC calculated using
c0- aumc
The AUMC calculated using
concandtimewithoutc0
Details
The AUXC for intravenous (IV) dosing extrapolates the AUXC back from the first
measurement to time 0 using c0 and the AUXC calculated by another method
(e.g., auclast or aumclast).
How the calculation proceeds depends on what is measured at time = 0:
- A concentration is measured at
time = 0 The AUXC between
time = 0and the next time point is calculated with the measured concentration (auxc_first) and withc0(auxc_second). The final AUXC isauxc + auxc_second - auxc_first.- No concentration at
time = 0andauxcwas calculated auxccomes from a method that extrapolates back totime = 0withconc.origin(zero; theaucintfamily), so that segment is replaced by the one usingc0in the same way.- No concentration at
time = 0andauxcisNA auxcisNAbecause an AUXC may not start before the first measurement.c0supplies that measurement, so the AUXC is calculated here fromc0and the measured data usingfun_auxcandauc.type.
The calculation for back-extrapolation is 100*(1 - auc/auciv). It
requires a measured concentration at time 0; without one, auc does not
describe the observed part of auciv (it either cannot be calculated or,
for the aucint family, already extrapolates back to time 0 with
conc.origin), so NA is returned.
Functions
pk.calc.auciv(): Calculate AUC for intravenous dosing with C0 back-extrapolationpk.calc.auciv_pbext(): Calculate the percent back-extrapolated AUC for IV administrationpk.calc.aumciv(): Calculate AUMC for intravenous dosing with C0 back-extrapolation
See also
Other AUC calculations:
pk.calc.auxc(),
pk.calc.auxcint()
Other AUMC calculations:
pk.calc.auxcint()