Calculate the last measurable excretion rate
Details
Collections are ordered by their midpoint time, matching
pk.calc.ertlst(), which gives the midpoint time of this same collection.
When no collection has a positive excretion rate, the result is 0.
See also
pk.calc.ertlst(), pk.calc.ermax()
Other Urine/Excretion parameters:
pk.calc.ae(),
pk.calc.clr(),
pk.calc.erint(),
pk.calc.ermax(),
pk.calc.ertlst(),
pk.calc.ertmax(),
pk.calc.fe(),
pk.calc.volpk()