Calculate the ratio of a parameter between two intervals
Source:R/secondary-parameters.R
pk.calc.ratio.RdCalculate the ratio of a parameter between two intervals
Value
test/reference, or NA where the reference is missing or is not
above zero (a ratio to a zero or negative reference is not interpretable).