Input restrictions are:
the conc and time must be the same length,
the time may have no NAs,
NA will be returned if:
the length of conc and time is 0
all conc is 0 or NA
pk.calc.tmax(conc, time, options = list(), first.tmax = NULL, check = TRUE)Concentration measured
Time of concentration measurement
List of changes to the default
PKNCA.options for calculations.
If there is more than time that matches the maximum concentration, should the first be considered as Tmax? If not, then the last is considered Tmax.
Run check.conc.time?
the time of the maximum concentration