Compute NCA for multiple intervals
Usage
pk.nca.intervals(
data_conc,
data_dose,
data_intervals,
options,
impute,
data_sparse_conc = NULL,
verbose = FALSE
)Arguments
- data_conc
A data.frame or tibble with standardized column names as output from
prepare_PKNCAconc(). With sparse PK this is the arithmetic-mean profile.- data_dose
A data.frame or tibble with standardized column names as output from
prepare_PKNCAdose()- data_intervals
A data.frame or tibble with standardized column names as output from
prepare_PKNCAintervals()- options
List of changes to the default PKNCA options (see
PKNCA.options())- impute
The column name in
data_intervalsto use for imputation- data_sparse_conc
For sparse PK, a data.frame or tibble of the pooled individual samples (including a
subjectcolumn) as output fromprepare_PKNCAconc();NULLfor dense PK- verbose
Indicate, by
message(), the current state of calculation.