Trough concentrations are selected as concentrations at the time of
dosing. An exponential curve is then fit through the data with a
different magnitude by treatment (as a factor) and a random
steady-state concentration and time to stead-state by subject (see
random.effects argument).
pk.tss.monoexponential(
...,
tss.fraction = 0.9,
output = c("population", "popind", "individual", "single"),
check = TRUE,
verbose = FALSE
)A scalar float for the first time when steady-state is
achieved or NA if it is not observed.
See pk.tss.data.prep
The fraction of steady-state required for calling steady-state
Which types of outputs should be produced?
population is the population estimate for time to
steady-state (from an nlme model), popind is the individual
estimate (from an nlme model), individual fits each
individual separately with a gnls model (requires more than one
individual; use single for one individual), and
single fits all the data to a single gnls model.
See pk.tss.data.prep.
Describe models as they are run, show convergence of the model (passed to the nlme function), and additional details while running.
Maganti L, Panebianco DL, Maes AL. Evaluation of Methods for Estimating Time to Steady State with Examples from Phase 1 Studies. AAPS Journal 10(1):141-7. doi:10.1208/s12248-008-9014-y
Other Time to steady-state calculations:
pk.tss.stepwise.linear(),
pk.tss()