Match spellings of a route of administration to the route PKNCA uses
Source:R/001-add.interval.col.R
pknca_match_route.RdMatch spellings of a route of administration to the route PKNCA uses
Value
A data.frame with one row for each element of x and the columns
route (one of pknca_routes(), or "iv" when the spelling is
intravascular but does not say which intravascular route it is) and dose_route ("extravascular" or
"intravascular", the values PKNCAdose() accepts for route). Both
are NA when the spelling is not known or x is NA.
See also
The Route synonyms section of pknca_routes() for the spellings
that are known.
Other Interval specifications:
add.interval.col(),
check.interval.specification(),
choose.auc.intervals(),
get.interval.cols(),
get.parameter.deps(),
interval_add_impute(),
interval_add_param(),
interval_add_secondary(),
pknca_cdisc_codes(),
pknca_check_parameter_classification(),
pknca_concepts(),
pknca_interval_table(),
pknca_parameter_table(),
pknca_presets(),
pknca_ref()
Examples
pknca_match_route(c("PO", "Intravenous", "IV BOLUS", "unknown"))
#> route dose_route
#> 1 extravascular extravascular
#> 2 iv intravascular
#> 3 iv_bolus intravascular
#> 4 <NA> <NA>