Mark a formalsmap entry as coming from the reference interval
Source:R/001-add.interval.col.R
pknca_ref.RdUsed in the formalsmap argument of add.interval.col() to declare that an
argument takes the value of param calculated in the reference interval
(the interval named by the <parameter>_ref column of the interval
specification) rather than in the current interval.
See also
add.interval.col(), the vignette "Secondary parameters"
Other Interval specifications:
add.interval.col(),
check.interval.specification(),
choose.auc.intervals(),
get.interval.cols(),
get.parameter.deps(),
interval_add_impute(),
interval_add_param(),
interval_add_secondary(),
pknca_check_parameter_classification(),
pknca_concepts(),
pknca_interval_table(),
pknca_parameter_table(),
pknca_presets()