Find the conversion factor between two units, when there is one
Source:R/unit-support.R
pknca_unit_reconcile_factor.RdThe conversions of pknca_units_table() are requested by the user and so
fail loudly when they cannot be made. This answers the different question of
whether two units PKNCA derived itself can be reconciled – units that are
unrelated (a concentration and an amount) or outside udunits ("IU/mL") are
an expected answer of "no" rather than a mistake.
Value
The number that a value in from units is multiplied by to express
it in to units, or NA_real_ when the two are not convertible or the
units package is not installed.