Determine the dosing interval (tau) to use for a calculation interval
Source:R/choose.intervals.R
resolve_dose_tau.RdA tau column in the interval specification takes precedence over
detection so that designs where only the steady-state dose is present in the
dosing data (nothing repeats, so nothing can be detected) can still be
calculated. Otherwise tau is detected from the group's dose times with
find.tau().
Usage
resolve_dose_tau(interval, time.dose, options = list())Arguments
- interval
One row of an interval definition (see
check.interval.specification())- time.dose
The dose times for the whole group (not just the interval; an interval one
taulong contains a single dose, so nothing repeats within it)- options
List of changes to the default PKNCA options (see
PKNCA.options())
See also
Other Interval determination:
choose.auc.intervals(),
find.tau()